CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_error.h File Reference

CCL

Macros | Enumerations | Functions
ccl_error.h File Reference
`#include "ccl_core.h"`

Go to the source code of this file.

## Macros
#define | CCL_ERROR_MEMORY 1
#define | CCL_ERROR_LINSPACE 2
#define | CCL_ERROR_INCONSISTENT 3
#define | CCL_ERROR_SPLINE 4
#define | CCL_ERROR_SPLINE_EV 5
#define | CCL_ERROR_INTEG 6
#define | CCL_ERROR_ROOT 7
#define | CCL_ERROR_CLASS 8
#define | CCL_ERROR_COMPUTECHI 9
#define | CCL_ERROR_MF 10
#define | CCL_ERROR_HMF_INTERP 11
#define | CCL_ERROR_PARAMETERS 12
#define | CCL_ERROR_NU_INT 13

## Enumerations
enum | CCLErrorPolicy { CCL_ERROR_POLICY_EXIT = 0, CCL_ERROR_POLICY_CONTINUE = 1 }

## Functions
void | ccl_raise_exception (int err, char *msg)
void | ccl_set_error_policy (CCLErrorPolicy error_policy)
void | ccl_check_status (ccl_cosmology *cosmo, int *status)
void | ccl_check_status_nocosmo (int *status)

## Macro Definition Documentation

## ◆ CCL_ERROR_CLASS

#define CCL_ERROR_CLASS 8

## ◆ CCL_ERROR_COMPUTECHI

#define CCL_ERROR_COMPUTECHI 9

## ◆ CCL_ERROR_HMF_INTERP

#define CCL_ERROR_HMF_INTERP 11

## ◆ CCL_ERROR_INCONSISTENT

#define CCL_ERROR_INCONSISTENT 3

## ◆ CCL_ERROR_INTEG

#define CCL_ERROR_INTEG 6

## ◆ CCL_ERROR_LINSPACE

#define CCL_ERROR_LINSPACE 2

## ◆ CCL_ERROR_MEMORY

#define CCL_ERROR_MEMORY 1

## ◆ CCL_ERROR_MF

#define CCL_ERROR_MF 10

## ◆ CCL_ERROR_NU_INT

#define CCL_ERROR_NU_INT 13

## ◆ CCL_ERROR_PARAMETERS

#define CCL_ERROR_PARAMETERS 12

## ◆ CCL_ERROR_ROOT

#define CCL_ERROR_ROOT 7

## ◆ CCL_ERROR_SPLINE

#define CCL_ERROR_SPLINE 4

## ◆ CCL_ERROR_SPLINE_EV

#define CCL_ERROR_SPLINE_EV 5

## Enumeration Type Documentation

## ◆ CCLErrorPolicy

enum CCLErrorPolicy

Enumerator
CCL_ERROR_POLICY_EXIT |
CCL_ERROR_POLICY_CONTINUE |

## Function Documentation

## ◆ ccl_check_status()

void ccl_check_status | ( | ccl_cosmology * | cosmo,
|  | int * | status
| ) |  |

Check the error status Given a status, check if any errors have occurred, based on the CCL_ERRORs defined so far.

Returns
  void

## ◆ ccl_check_status_nocosmo()

void ccl_check_status_nocosmo | ( | int * | status | ) |

Check the error status - no cosmology Given a status, check if any errors have occurred, based on the CCL_ERRORs defined so far.

Returns
  void

## ◆ ccl_raise_exception()

void ccl_raise_exception | ( | int | err,
|  | char * | msg
| ) |  |

Raise an exception Given a status, give an error message.

Returns
  void

## ◆ ccl_set_error_policy()

void ccl_set_error_policy | ( | CCLErrorPolicy | error_policy | ) |

Set the error policy error_policy the error policy

Returns
  void